/**
 * Core Services API
 * Use the Core Services API to manage resources such as virtual cloud networks (VCNs),
compute instances, and block storage volumes. For more information, see the console
documentation for the [Networking](/iaas/Content/Network/Concepts/overview.htm),
[Compute](/iaas/Content/Compute/Concepts/computeoverview.htm), and
[Block Volume](/iaas/Content/Block/Concepts/overview.htm) services.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
export interface CreateVirtualCircuitDetails {
    /**
      * The provisioned data rate of the connection. To get a list of the
  * available bandwidth levels (that is, shapes), see
  * {@link #listFastConnectProviderVirtualCircuitBandwidthShapes(ListFastConnectProviderVirtualCircuitBandwidthShapesRequest) listFastConnectProviderVirtualCircuitBandwidthShapes}.
  * <p>
  Example: `10 Gbps`
  *
      */
    "bandwidthShapeName"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to contain the virtual circuit.
     *
     */
    "compartmentId": string;
    /**
     * Create a `CrossConnectMapping` for each cross-connect or cross-connect
     * group this virtual circuit will run on.
     *
     */
    "crossConnectMappings"?: Array<model.CrossConnectMapping>;
    /**
     * The routing policy sets how routing information about the Oracle cloud is shared over a public virtual circuit.
     * Policies available are: `ORACLE_SERVICE_NETWORK`, `REGIONAL`, `MARKET_LEVEL`, and `GLOBAL`.
     * See [Route Filtering](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/routingonprem.htm#route_filtering) for details.
     * By default, routing information is shared for all routes in the same market.
     *
     */
    "routingPolicy"?: Array<CreateVirtualCircuitDetails.RoutingPolicy>;
    /**
     * Deprecated. Instead use `customerAsn`.
     * If you specify values for both, the request will be rejected.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "customerBgpAsn"?: number;
    /**
      * Your BGP ASN (either public or private). Provide this value only if
  * there's a BGP session that goes from your edge router to Oracle.
  * Otherwise, leave this empty or null.
  * Can be a 2-byte or 4-byte ASN. Uses \"asplain\" format.
  * <p>
  Example: `12345` (2-byte) or `1587232876` (4-byte)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "customerAsn"?: number;
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a
  * namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable.
     * Avoid entering confidential information.
     *
     */
    "displayName"?: string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no
  * predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: `{\"Department\": \"Finance\"}`
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * For private virtual circuits only. The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the {@link Drg}
     * that this virtual circuit uses.
     *
     */
    "gatewayId"?: string;
    /**
     * Deprecated. Instead use `providerServiceId`.
     * To get a list of the provider names, see
     * {@link #listFastConnectProviderServices(ListFastConnectProviderServicesRequest) listFastConnectProviderServices}.
     *
     */
    "providerName"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the service offered by the provider (if you're connecting
     * via a provider). To get a list of the available service offerings, see
     * {@link #listFastConnectProviderServices(ListFastConnectProviderServicesRequest) listFastConnectProviderServices}.
     *
     */
    "providerServiceId"?: string;
    /**
     * The service key name offered by the provider (if the customer is connecting via a provider).
     *
     */
    "providerServiceKeyName"?: string;
    /**
     * Deprecated. Instead use `providerServiceId`.
     * To get a list of the provider names, see
     * {@link #listFastConnectProviderServices(ListFastConnectProviderServicesRequest) listFastConnectProviderServices}.
     *
     */
    "providerServiceName"?: string;
    /**
     * For a public virtual circuit. The public IP prefixes (CIDRs) the customer wants to
     * advertise across the connection.
     *
     */
    "publicPrefixes"?: Array<model.CreateVirtualCircuitPublicPrefixDetails>;
    /**
     * The Oracle Cloud Infrastructure region where this virtual
     * circuit is located.
     * Example: `phx`
     *
     */
    "region"?: string;
    /**
     * The type of IP addresses used in this virtual circuit. PRIVATE
     * means [RFC 1918](https://tools.ietf.org/html/rfc1918) addresses
     * (10.0.0.0/8, 172.16/12, and 192.168/16).
     *
     */
    "type": CreateVirtualCircuitDetails.Type;
    /**
     * The layer 3 IP MTU to use with this virtual circuit.
     */
    "ipMtu"?: model.VirtualCircuitIpMtu;
}
export declare namespace CreateVirtualCircuitDetails {
    enum RoutingPolicy {
        OracleServiceNetwork = "ORACLE_SERVICE_NETWORK",
        Regional = "REGIONAL",
        MarketLevel = "MARKET_LEVEL",
        Global = "GLOBAL"
    }
    enum Type {
        Public = "PUBLIC",
        Private = "PRIVATE"
    }
    function getJsonObj(obj: CreateVirtualCircuitDetails): object;
    function getDeserializedJsonObj(obj: CreateVirtualCircuitDetails): object;
}
