/**
 * Core Services API
 * Use the Core Services API to manage resources such as virtual cloud networks (VCNs),
compute instances, and block storage volumes. For more information, see the console
documentation for the [Networking](/iaas/Content/Network/Concepts/overview.htm),
[Compute](/iaas/Content/Compute/Concepts/computeoverview.htm), and
[Block Volume](/iaas/Content/Block/Concepts/overview.htm) services.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A compute instance shape that can be used in {@link #launchInstance(LaunchInstanceRequest) launchInstance}.
 * For more information, see [Overview of the Compute Service](https://docs.cloud.oracle.com/iaas/Content/Compute/Concepts/computeoverview.htm) and
 * [Compute Shapes](https://docs.cloud.oracle.com/iaas/Content/Compute/References/computeshapes.htm).
 *
 */
export interface Shape {
    /**
     * For a subcore burstable VM, the supported baseline OCPU utilization for instances that use this shape.
     *
     */
    "baselineOcpuUtilizations"?: Array<Shape.BaselineOcpuUtilizations>;
    /**
     * For a subcore burstable VM, the minimum total baseline OCPUs required. The total baseline OCPUs is equal to
     * baselineOcpuUtilization chosen multiplied by the number of OCPUs chosen.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "minTotalBaselineOcpusRequired"?: number;
    /**
     * The name of the shape. You can enumerate all available shapes by calling
     * {@link #listShapes(ListShapesRequest) listShapes}.
     *
     */
    "shape": string;
    /**
     * A short description of the shape's processor (CPU).
     *
     */
    "processorDescription"?: string;
    /**
     * The default number of OCPUs available for this shape.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "ocpus"?: number;
    /**
     * The default amount of memory available for this shape, in gigabytes.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "memoryInGBs"?: number;
    /**
     * The networking bandwidth available for this shape, in gigabits per second.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "networkingBandwidthInGbps"?: number;
    /**
     * The maximum number of VNIC attachments available for this shape.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxVnicAttachments"?: number;
    /**
     * The number of GPUs available for this shape.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "gpus"?: number;
    /**
      * A short description of the graphics processing unit (GPU) available for this shape.
  * <p>
  If the shape does not have any GPUs, this field is `null`.
  *
      */
    "gpuDescription"?: string;
    /**
     * The number of local disks available for this shape.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "localDisks"?: number;
    /**
      * The aggregate size of the local disks available for this shape, in gigabytes.
  * <p>
  If the shape does not have any local disks, this field is `null`.
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "localDisksTotalSizeInGBs"?: number;
    /**
      * A short description of the local disks available for this shape.
  * <p>
  If the shape does not have any local disks, this field is `null`.
  *
      */
    "localDiskDescription"?: string;
    /**
     * Whether live migration is supported for this shape.
     *
     */
    "isLiveMigrationSupported"?: boolean;
    "ocpuOptions"?: model.ShapeOcpuOptions;
    "memoryOptions"?: model.ShapeMemoryOptions;
    "networkingBandwidthOptions"?: model.ShapeNetworkingBandwidthOptions;
    "maxVnicAttachmentOptions"?: model.ShapeMaxVnicAttachmentOptions;
    "platformConfigOptions"?: model.ShapePlatformConfigOptions;
}
export declare namespace Shape {
    enum BaselineOcpuUtilizations {
        Baseline18 = "BASELINE_1_8",
        Baseline12 = "BASELINE_1_2",
        Baseline11 = "BASELINE_1_1",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: Shape): object;
    function getDeserializedJsonObj(obj: Shape): object;
}
